##  Inventory Builder
The inventory builder uses AI to analyze diagrams and images to automatically extract relevant architectural elements. The analysis discovers appropriate fact sheets and their relationships, which you can review and create corresponding fact sheets to accelerate your inventory-building process.
